@@ -1,8 +1,10 @@
 import pymug
 
 def main():
-    print('Greetings From The Pymug (Python Mauritius User Group')
+    print('Greetings From The Pymug (Python Mauritius User Group)')
     print('github.com/pymug')
 
+print('pymug says hello main')
+
 if __name__ == '__main__':
     main()
\ No newline at end of file
